@@ -21,17 +21,18 @@ import re
 import sys
 from concurrent.futures import Future, ThreadPoolExecutor
 from threading import Event
-from typing import Any, Callable, List, Optional, TypeVar, Union
+from typing import Any, Callable, List, Optional, TextIO, TypeVar, Union
 
 from pygls import IS_WIN, IS_PYODIDE
 from pygls.lsp import ConfigCallbackType, ShowDocumentCallbackType
 from pygls.exceptions import PyglsError, JsonRpcException, FeatureRequestError
 from lsprotocol.types import (
     ClientCapabilities,
-    ConfigurationParams, Diagnostic, MessageType, RegistrationParams,
+    Diagnostic, MessageType, RegistrationParams,
     ServerCapabilities, ShowDocumentParams,
     TextDocumentSyncKind, UnregistrationParams,
-    WorkspaceApplyEditResponse, WorkspaceEdit
+    WorkspaceApplyEditResponse, WorkspaceEdit,
+    WorkspaceConfigurationParams
 )
 from pygls.progress import Progress
 from pygls.protocol import LanguageServerProtocol, default_converter
@@ -218,7 +219,7 @@ class Server:
         logger.info('Closing the event loop.')
         self.loop.close()
 
-    def start_io(self, stdin=None, stdout=None):
+    def start_io(self, stdin: Optional[TextIO] = None, stdout: Optional[TextIO] = None):
         """Starts IO server."""
         logger.info('Starting IO server')
 
@@ -251,7 +252,7 @@ class Server:
         self.lsp.connection_made(transport)
         self.lsp._send_only_body = True  # Don't send headers within the payload
 
-    def start_tcp(self, host, port):
+    def start_tcp(self, host: str, port: int) -> None:
         """Starts TCP server."""
         logger.info('Starting TCP server on %s:%s', host, port)
 
@@ -266,10 +267,10 @@ class Server:
         finally:
             self.shutdown()
 
-    def start_ws(self, host, port):
+    def start_ws(self, host: str, port: int) -> None:
         """Starts WebSocket server."""
         try:
-            import websockets
+            from websockets.server import serve
         except ImportError:
             logger.error('Run `pip install pygls[ws]` to install `websockets`.')
             sys.exit(1)
@@ -287,7 +288,7 @@ class Server:
                     json.loads(message, object_hook=self.lsp._deserialize_message)
                 )
 
-        start_server = websockets.serve(connection_made, host, port, loop=self.loop)
+        start_server = serve(connection_made, host, port, loop=self.loop)
         self._server = start_server.ws_server
         self.loop.run_until_complete(start_server)
 
@@ -356,7 +357,9 @@ class LanguageServer(Server):
         self.version = version
         super().__init__(protocol_cls, converter_factory, loop, max_workers)
 
-    def apply_edit(self, edit: WorkspaceEdit, label: str = None) -> WorkspaceApplyEditResponse:
+    def apply_edit(
+        self, edit: WorkspaceEdit, label: Optional[str] = None
+    ) -> WorkspaceApplyEditResponse:
         """Sends apply edit request to the client."""
         return self.lsp.apply_edit(edit, label)
 
@@ -387,12 +390,12 @@ class LanguageServer(Server):
         """
         return self.lsp.fm.feature(feature_name, options)
 
-    def get_configuration(self, params: ConfigurationParams,
+    def get_configuration(self, params: WorkspaceConfigurationParams,
                           callback: Optional[ConfigCallbackType] = None) -> Future:
         """Gets the configuration settings from the client."""
         return self.lsp.get_configuration(params, callback)
 
-    def get_configuration_async(self, params: ConfigurationParams) -> asyncio.Future:
+    def get_configuration_async(self, params: WorkspaceConfigurationParams) -> asyncio.Future:
         """Gets the configuration settings from the client. Should be called with `await`"""
         return self.lsp.get_configuration_async(params)
 
@@ -405,9 +408,23 @@ class LanguageServer(Server):
         """Gets the object to manage client's progress bar."""
         return self.lsp.progress
 
-    def publish_diagnostics(self, doc_uri: str, diagnostics: List[Diagnostic]):
-        """Sends diagnostic notification to the client."""
-        self.lsp.publish_diagnostics(doc_uri, diagnostics)
+    def publish_diagnostics(
+        self,
+        uri: str,
+        diagnostics: Optional[List[Diagnostic]] = None,
+        version: Optional[int] = None,
+        **kwargs
+    ):
+        """
+        Sends diagnostic notification to the client.
+        """
+        params = self.lsp._construct_publish_diagnostic_type(
+            uri,
+            diagnostics,
+            version,
+            **kwargs
+        )
+        self.lsp.publish_diagnostics(params, **kwargs)
 
     def register_capability(self, params: RegistrationParams,
                             callback: Optional[Callable[[], None]] = None) -> Future:
